==> style-o-matic-1.1.5.tgz: package/es/components/Loading/Loading.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, setCorePropDefaults, getValidProps, ROLE } from "../../lib";
import "./Loading.css";

var Loading = (_temp = _class = function (_CoreComponent) {
  _inherits(Loading, _CoreComponent);

  function Loading() {
    _classCallCheck(this, Loading);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  Loading.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      "div",
      props,
      React.createElement(
        "div",
        { className: "loading-cube" },
        React.createElement("div", { className: "cube cube1" }),
        React.createElement("div", { className: "cube cube2" }),
        React.createElement("div", { className: "cube cube3" }),
        React.createElement("div", { className: "cube cube4" }),
        React.createElement("div", { className: "cube cube5" }),
        React.createElement("div", { className: "cube cube6" }),
        React.createElement("div", { className: "cube cube7" }),
        React.createElement("div", { className: "cube cube8" }),
        React.createElement("div", { className: "cube cube9" })
      )
    );
  };

  return Loading;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.LOADING
}), _temp);


export default Loading;

==> style-o-matic-1.1.37.tgz: package/es/components/Loading/Loading.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getCorePropDefaults, getValidProps, ROLE } from "../../lib";
import "./Loading.css";

var Loading = (_temp = _class = function (_CoreComponent) {
  _inherits(Loading, _CoreComponent);

  function Loading() {
    _classCallCheck(this, Loading);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  Loading.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      "div",
      props,
      React.createElement(
        "div",
        { className: "loading-cube" },
        React.createElement("div", { className: "cube cube1" }),
        React.createElement("div", { className: "cube cube2" }),
        React.createElement("div", { className: "cube cube3" }),
        React.createElement("div", { className: "cube cube4" }),
        React.createElement("div", { className: "cube cube5" }),
        React.createElement("div", { className: "cube cube6" }),
        React.createElement("div", { className: "cube cube7" }),
        React.createElement("div", { className: "cube cube8" }),
        React.createElement("div", { className: "cube cube9" })
      )
    );
  };

  return Loading;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.LOADING
}), _temp);


export default Loading;
